@@ -168,7 +168,7 @@ class BoardCategory(BaseCategory):
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: typing.Optional[Literal[False]] = ...,
-        sort: Literal["asc", "desc"] = None,
+        sort: typing.Optional[Literal["asc", "desc"]] = None,
         **kwargs
     ) -> GetCommentsResponseModel:
         ...
@@ -183,7 +183,7 @@ class BoardCategory(BaseCategory):
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: Literal[True] = ...,
-        sort: Literal["asc", "desc"] = None,
+        sort: typing.Optional[Literal["asc", "desc"]] = None,
         **kwargs
     ) -> GetCommentsExtendedResponseModel:
         ...
@@ -226,11 +226,11 @@ class BoardCategory(BaseCategory):
         self,
         group_id: int,
         topic_ids: typing.Optional[typing.List[int]] = None,
-        order: Literal[1, 2, -1, -2, 0] = None,
+        order: typing.Optional[Literal[1, 2, -1, -2, 0]] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: typing.Optional[Literal[False]] = ...,
-        preview: Literal[1, 2, 0] = None,
+        preview: typing.Optional[Literal[1, 2, 0]] = None,
         preview_length: typing.Optional[int] = None,
         **kwargs
     ) -> GetTopicsResponseModel:
@@ -241,11 +241,11 @@ class BoardCategory(BaseCategory):
         self,
         group_id: int,
         topic_ids: typing.Optional[typing.List[int]] = None,
-        order: Literal[1, 2, -1, -2, 0] = None,
+        order: typing.Optional[Literal[1, 2, -1, -2, 0]] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: Literal[True] = ...,
-        preview: Literal[1, 2, 0] = None,
+        preview: typing.Optional[Literal[1, 2, 0]] = None,
         preview_length: typing.Optional[int] = None,
         **kwargs
     ) -> GetTopicsExtendedResponseModel:
