@@ -67,8 +67,8 @@ class LikesCategory(BaseCategory):
         owner_id: typing.Optional[int] = None,
         item_id: typing.Optional[int] = None,
         page_url: typing.Optional[str] = None,
-        filter: Literal["likes", "copies"] = None,
-        friends_only: Literal[0, 1, 2, 3] = None,
+        filter: typing.Optional[Literal["likes", "copies"]] = None,
+        friends_only: typing.Optional[Literal[0, 1, 2, 3]] = None,
         extended: typing.Optional[Literal[False]] = ...,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
@@ -84,8 +84,8 @@ class LikesCategory(BaseCategory):
         owner_id: typing.Optional[int] = None,
         item_id: typing.Optional[int] = None,
         page_url: typing.Optional[str] = None,
-        filter: Literal["likes", "copies"] = None,
-        friends_only: Literal[0, 1, 2, 3] = None,
+        filter: typing.Optional[Literal["likes", "copies"]] = None,
+        friends_only: typing.Optional[Literal[0, 1, 2, 3]] = None,
         extended: Literal[True] = ...,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
