@@ -1,3 +1,5 @@
+import typing
+
 from typing_extensions import Literal
 from vkbottle_types.responses.base import OkResponse
 from vkbottle_types.responses.streaming import (
@@ -19,8 +21,10 @@ class StreamingCategory(BaseCategory):
 
     async def set_settings(
         self,
-        monthly_tier: Literal[
-            "tier_1", "tier_2", "tier_3", "tier_4", "tier_5", "tier_6", "unlimited"
+        monthly_tier: typing.Optional[
+            Literal[
+                "tier_1", "tier_2", "tier_3", "tier_4", "tier_5", "tier_6", "unlimited"
+            ]
         ] = None,
         **kwargs
     ) -> int:
