@@ -15,6 +15,10 @@ from vkbottle_types.objects import (
 from .base_response import BaseResponse
 
 
+class GenericResponse(BaseResponse):
+    response: "GenericResponseModel"
+
+
 class GetBannedExtendedResponse(BaseResponse):
     response: "GetBannedExtendedResponseModel"
 
@@ -39,18 +43,10 @@ class GetMentionsResponse(BaseResponse):
     response: "GetMentionsResponseModel"
 
 
-class GetRecommendedResponse(BaseResponse):
-    response: "GetRecommendedResponseModel"
-
-
 class GetSuggestedSourcesResponse(BaseResponse):
     response: "GetSuggestedSourcesResponseModel"
 
 
-class GetResponse(BaseResponse):
-    response: "GetResponseModel"
-
-
 class IgnoreItemResponse(BaseResponse):
     response: "IgnoreItemResponseModel"
 
@@ -67,6 +63,13 @@ class SearchResponse(BaseResponse):
     response: "SearchResponseModel"
 
 
+class GenericResponseModel(BaseResponse):
+    items: typing.Optional[typing.List["NewsfeedNewsfeedItem"]] = None
+    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
+    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
+    new_returned_news_items_count: typing.Optional[int] = None
+
+
 class GetBannedExtendedResponseModel(BaseResponse):
     profiles: typing.Optional[typing.List["UsersUserFull"]] = None
     groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
@@ -99,25 +102,11 @@ class GetMentionsResponseModel(BaseResponse):
     items: typing.Optional[typing.List["WallWallpostToId"]] = None
 
 
-class GetRecommendedResponseModel(BaseResponse):
-    items: typing.Optional[typing.List["NewsfeedNewsfeedItem"]] = None
-    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
-    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
-    next_from: typing.Optional[str] = None
-
-
 class GetSuggestedSourcesResponseModel(BaseResponse):
     count: typing.Optional[int] = None
     items: typing.Optional[typing.List["UsersSubscriptionsItem"]] = None
 
 
-class GetResponseModel(BaseResponse):
-    items: typing.Optional[typing.List["NewsfeedNewsfeedItem"]] = None
-    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
-    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
-    next_from: typing.Optional[str] = None
-
-
 class IgnoreItemResponseModel(BaseResponse):
     status: typing.Optional[bool] = None
 
