@@ -1,6 +1,6 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import (
     AppsApp,
     BaseBoolInt,
@@ -12,17 +12,19 @@ from vkbottle_types.objects import (
     VideoVideo,
 )
 
+from .base_response import BaseResponse
+
 
 class GetResponse(BaseResponse):
-    response: "GetResponseModel" = None
+    response: "GetResponseModel"
 
 
 class MarkAsViewedResponse(BaseResponse):
-    response: BaseBoolInt = None
+    response: BaseBoolInt
 
 
 class SendMessageResponse(BaseResponse):
-    response: typing.List["NotificationsSendMessageItem"] = None
+    response: typing.List["NotificationsSendMessageItem"]
 
 
 class GetResponseModel(BaseResponse):
