@@ -1,11 +1,13 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import SearchHint
 
+from .base_response import BaseResponse
+
 
 class GetHintsResponse(BaseResponse):
-    response: "GetHintsResponseModel" = None
+    response: "GetHintsResponseModel"
 
 
 class GetHintsResponseModel(BaseResponse):
