@@ -28,10 +28,6 @@ class GetByIdExtendedResponse(BaseResponse):
     response: "GetByIdExtendedResponseModel"
 
 
-class GetByIdResponse(BaseResponse):
-    response: "GetByIdResponseModel"
-
-
 class GetPhotoUploadServerResponse(BaseResponse):
     response: "GetPhotoUploadServerResponseModel"
 
@@ -87,11 +83,6 @@ class GetByIdExtendedResponseModel(BaseResponse):
     groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
 
 
-class GetByIdResponseModel(BaseResponse):
-    count: typing.Optional[int] = None
-    items: typing.Optional[typing.List["StoriesStory"]] = None
-
-
 class GetPhotoUploadServerResponseModel(BaseResponse):
     upload_url: typing.Optional[str] = None
     user_ids: typing.Optional[typing.List[int]] = None
